==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/test/test_pyedsl/test_dbsignal/test_nxcals/test_NxcalsDbSignal.py <==
import warnings
import unittest
from unittest import mock

from lhcsmapi.pyedsl.dbsignal.nxcals.NxcalsDbSignal import NxcalsDbSignal


class TestNxcalsDbSignal(unittest.TestCase):

    def test_init_exception(self):
        # arrange

        # act
        # assert
        with self.assertRaises(Exception) as context:
            NxcalsDbSignal(t_start=1, t_end=1.5, nxcals_system='WINCCOA', signal="U_RES")

        self.assertEqual('You have to provide an instance of spark connector via the spark keyword',
                         str(context.exception))

    def test_read_system_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsDbSignal(t_start=1, t_end=1.5, nxcals_system='WINCCOA', signal="U_RES", spark=spark_mock).read()

        self.assertEqual("""NXCALS query failed with the parameters, signal: U_RES, start time: 1, end time: 1.5,
                nxcals_system WINCCOA failed

                Empty signal returned.
                ___________________________________________________________________________________
                You can reproduce the error using the raw NXCALS API:

                from cern.nxcals.pyquery.builders import *

                VariableQuery.builder(spark)\\
                .system(WINCCOA)\\
                .startTime(1).endTime(1.5)\\
                .variable(U_RES)\\
                .buildDataset()\\
                .select('nxcals_timestamp', 'nxcals_value').toPandas()
                """, str(w[0].message))

    def test_read_system_device_property_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsDbSignal(nxcals_system='CMW', nxcals_device='RPTE.UA43.RB.A34', nxcals_property='SUB', signal="I_MEAS",
                           t_start=1, t_end=1.5, spark=spark_mock).read()

        self.assertEqual("""NXCALS query failed with the parameters, signal: I_MEAS, start time: 1, end time: 1.5, 
                nxcals_system CMW, nxcals_device RPTE.UA43.RB.A34, nxcals_property SUB

                Empty signal returned.
                ___________________________________________________________________________________
                You can reproduce the error using the raw NXCALS API:

                from cern.nxcals.pyquery.builders import *
                DevicePropertyQuery.builder(spark)\\
                .system('CMW')\\
                .startTime('1').endTime('1.5').entity()\\
                .device('RPTE.UA43.RB.A34').property('SUB').buildDataset()\\
                .select('acqStamp', I_MEAS).toPandas()
                """, str(w[0].message))

==> lhcsmapi-1.4.70.tar.gz: lhcsmapi-1.4.70/test/test_pyedsl/test_dbsignal/test_nxcals/test_NxcalsDbSignal.py <==
import warnings
import unittest
from unittest import mock

from lhcsmapi.pyedsl.dbsignal.nxcals.NxcalsDbSignal import NxcalsDbSignal


class TestNxcalsDbSignal(unittest.TestCase):

    def test_init_exception(self):
        # arrange

        # act
        # assert
        with self.assertRaises(Exception) as context:
            NxcalsDbSignal(t_start=1, t_end=1.5, nxcals_system='WINCCOA', signal="U_RES")

        self.assertEqual('You have to provide an instance of spark connector via the spark keyword',
                         str(context.exception))

    def test_read_system_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsDbSignal(t_start=1, t_end=1.5, nxcals_system='WINCCOA', signal="U_RES", spark=spark_mock).read()

        self.assertEqual("name 'VariableQuery' is not defined", str(w[0].message))
        self.assertEqual("""NXCALS query failed with the parameters, signal: U_RES, start time: 1, end time: 1.5,
                nxcals_system WINCCOA failed

                Empty signal returned.
                ___________________________________________________________________________________
                You can reproduce the error using the raw NXCALS API:

                from cern.nxcals.pyquery.builders import *

                VariableQuery.builder(spark)\\
                .system('WINCCOA')\\
                .startTime('1').endTime('1.5')\\
                .variable('U_RES')\\
                .buildDataset()\\
                .select('nxcals_timestamp', 'nxcals_value').toPandas()
                """, str(w[1].message))

    def test_read_system_device_property_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsDbSignal(nxcals_system='CMW', nxcals_device='RPTE.UA43.RB.A34', nxcals_property='SUB', signal="I_MEAS",
                           t_start=1, t_end=1.5, spark=spark_mock).read()
        self.assertEqual("name 'DevicePropertyQuery' is not defined", str(w[0].message))
        self.assertEqual("""NXCALS query failed with the parameters, signal: I_MEAS, start time: 1, end time: 1.5, 
                nxcals_system CMW, nxcals_device RPTE.UA43.RB.A34, nxcals_property SUB

                Empty signal returned.
                ___________________________________________________________________________________
                You can reproduce the error using the raw NXCALS API:

                from cern.nxcals.pyquery.builders import *
                DevicePropertyQuery.builder(spark)\\
                .system('CMW')\\
                .startTime('1').endTime('1.5').entity()\\
                .device('RPTE.UA43.RB.A34').property('SUB').buildDataset()\\
                .select('acqStamp', 'I_MEAS').toPandas()
                """, str(w[1].message))
